==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/k8s/resource_k8s_cp/main.tf <==
/*
Пример использования
Ресурса k8s
Ресурс позволяет:
1. Создавать кластер
2. Редактировать кластер
3. Удалять кластер
4. Настроить мастер-узел
5. Изменить кол-во ВМ в мастер-узле
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator  = "decs3o"
  oauth2_url     = "https://sso.digitalenergy.online"
  controller_url = "https://mr4.digitalenergy.online"
  app_id         = ""
  app_secret     = ""
}

resource "decort_cb_k8s_cp" "cp" {
  #название кластера
  #обязательный параметр
  #тип - строка
  name = "k8s-cp"

  #k8sCI ID
  #обязательный параметр
  #тип - целое число
  k8sci_id = 55

  #плагин сети
  #обязательный параметр
  #возможные значения - "flannel", "weavenet", "calico"
  #тип - строка
  network_plugin = "flannel"

  #id ресурсной группы
  #обязательный параметр
  #тип - целое число
  rg_id = 1387

  #кол-во ядер мастер-узла
  #опциональный параметр
  #тип - целое число
  cpu = 2

  #объем RAM мастер-узла
  #опциональный параметр
  #тип - целое число
  ram = 2048

  #кол-во ВМ мастер-узла (1, 3 или 5)
  #опциональный параметр
  #тип - целое число
  num = 1

  #размер диска мастер-узла
  #опциональный параметр
  #тип - целое число
  disk = 10

  #описание кластера
  #опциональный параметр
  #тип - строка
  desc = "<DESCRIPTION>"

  #id extnet
  #опциональный параметр
  #тип - целое число
  extnet_id = 0

  #id vins
  #опциональный параметр
  #тип - целое число
  vins_id = 1234

  #sep ip
  #опциональный параметр
  #тип - целое число
  sep_id = 0

  #название пула
  #опциональный параметр
  #тип - строка
  sep_pool = "pool"

  #старт/стоп кластера
  #опциональный параметр
  #тип - булев
  start = true

  #включить/отключить кластер
  #опциональный параметр
  #тип - булев
  enabled = true

  #удалить кластер безвозвратно
  #опциональный параметр
  #тип - булев
  permanently = true

  #восстановить кластер из корзины
  #опциональный параметр
  #тип - булев
  restore = true

  #создать кластер с/без балансировщика нагрузки
  #опциональный параметр
  #тип - булев
  with_lb = true

  #позволяет создать схему отказоустройчивой LB
  #опциональный параметр
  #тип - булев
  ha_mode = true

  #дополнительные SAN (Subject Alternative Names) для использования в процессе автоматического выписывания сертификата Кластера Kubernetes;
  #возможность взаимодействовать с кластером по FQDN
  #параметр получает список строк – IP-адреса и/или DNS (по формату RFC 1123 c поддержкой wildcard)
  #опциональный параметр
  #тип - массив строк
  additional_sans = ["192.168.201.0","192.168.201.1"]

  #используется для определения настроек и действий, которые должны быть выполнены перед запуском любого другого компонента в кластере
  #это позволяет вам настраивать такие вещи, как регистрация node, настройка network и другие задачи инициализации
  #опциональный параметр
  #тип - строка
  init_config = "{JSON string}"

  #используется для определения глобальных настроек и конфигураций для всего кластера
  #он включает в себя такие параметры, как имя кластера, настройки DNS, методы аутентификации и другие конфигурации в масштабах кластера
  #опциональный параметр
  #тип - строка
  cluster_config = "{JSON string}"

  #используется для настройки поведения и параметров Kubelet, который является агентом primary node, запускаемым на каждом node кластера
  #он включает в себя такие параметры, как IP-адрес node, распределение ресурсов, политики удаления модулей и другие конфигурации, специфичные для Kubelet
  #опциональный параметр
  #тип - строка
  kubelet_config = "{JSON string}"

  #используется для настройки поведения и параметров присоединения node к кластеру
  #он включает в себя такие параметры, как режим прокси-сервера, диапазоны IP-адресов кластера и другие конфигурации, специфичные для Kube-proxy
  #опциональный параметр
  #тип - строка
  kube_proxy_config = "{JSON string}"

  #используется для настройки поведения и параметров присоединения node к кластеру
  #он включает в себя такие параметры, как cluster's control plane endpoint, токен и ключ сертификата
  #опциональный параметр
  #тип - строка
  join_config = "{JSON string}"

  #при создании кластере использовать подключение только к сети ExtNet
  #опциональный параметр
  #тип - булев
  extnet_only = true

  #добавить ssl-сертификат в формате x509 pem
  #опциональный параметр
  #тип - файл с форматом в виде .crt
  oidc_cert = file("ca.crt")

  #тип эмулируемой системы
  #опциональный параметр
  #тип - строка
  chipset = "i440fx"

  #пользовательские значения sysctl для LB
  #опциональный параметр
  #тип - массив мап
  lb_sysctl_params = [{ key1 = "value1", key2 = "value2" }]
}

output "cp_out" {
  value = decort_cb_k8s_cp.cp
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/k8s/resource_k8s_cp/main.tf <==
/*
Пример использования
Ресурса k8s
Ресурс позволяет:
1. Создавать кластер
2. Редактировать кластер
3. Удалять кластер
4. Настроить мастер-узел
5. Изменить кол-во ВМ в мастер-узле
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator  = "decs3o"
  oauth2_url     = "https://sso.digitalenergy.online"
  controller_url = "https://mr4.digitalenergy.online"
  app_id         = ""
  app_secret     = ""
}

resource "decort_cb_k8s_cp" "cp" {
  #название кластера
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  name = "k8s-cp"

  #k8sCI ID
  #обязательный параметр
  #тип - целое число
  #используется при создании
  k8sci_id = 55

  #плагин сети
  #обязательный параметр
  #возможные значения - "flannel", "weavenet", "calico"
  #тип - строка
  #используется при создании
  network_plugin = "flannel"

  #id ресурсной группы
  #обязательный параметр
  #тип - целое число
  #используется при создании
  rg_id = 1387

  #кол-во ядер мастер-узла
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #cpu = 2

  #объем RAM мастер-узла
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #ram = 2048

  #кол-во ВМ мастер-узла (1, 3 или 5)
  #опциональный параметр
  #тип - целое число
  #используется при создании и обновлении
  #num = 1

  #размер диска мастер-узла
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #disk = 10

  #описание кластера
  #опциональный параметр
  #тип - строка
  #используется при создании и обновлении
  #desc = "<DESCRIPTION>"

  #id extnet
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #extnet_id = 0

  #id vins
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #vins_id = 1234

  #sep ip
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #sep_id = 0

  #название пула
  #опциональный параметр
  #тип - строка
  #используется при создании
  #sep_pool = "pool"

  #старт/стоп кластера
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #start = true

  #включить/отключить кластер
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #enabled = true

  #флаг для удаления k8s_cp, без возможности восстановления
  #опциональный параметр
  #тип - булев
  #используется при удалении
  #permanently = true

  #восстановить кластер из корзины
  #опциональный параметр
  #тип - булев
  #используется при обновлении
  #restore = true

  #создать кластер с/без балансировщика нагрузки
  #опциональный параметр
  #тип - булев
  #используется при создании
  #with_lb = true

  #создать схему отказоустройчивой LB
  #опциональный параметр
  #тип - булев
  #используется при создании
  #ha_mode = true

  #дополнительные SAN (Subject Alternative Names) для использования в процессе автоматического выписывания сертификата Кластера Kubernetes;
  #возможность взаимодействовать с кластером по FQDN
  #параметр получает список строк – IP-адреса и/или DNS (по формату RFC 1123 c поддержкой wildcard)
  #опциональный параметр
  #тип - массив строк
  #используется при создании
  #additional_sans = ["192.168.201.0","192.168.201.1"]

  #используется для определения настроек и действий, которые должны быть выполнены перед запуском любого другого компонента в кластере
  #это позволяет вам настраивать такие вещи, как регистрация node, настройка network и другие задачи инициализации
  #опциональный параметр
  #тип - строка
  #используется при создании
  #init_config = "{JSON string}"

  #используется для определения глобальных настроек и конфигураций для всего кластера
  #он включает в себя такие параметры, как имя кластера, настройки DNS, методы аутентификации и другие конфигурации в масштабах кластера
  #опциональный параметр
  #тип - строка
  #используется при создании
  #cluster_config = "{JSON string}"

  #используется для настройки поведения и параметров Kubelet, который является агентом primary node, запускаемым на каждом node кластера
  #он включает в себя такие параметры, как IP-адрес node, распределение ресурсов, политики удаления модулей и другие конфигурации, специфичные для Kubelet
  #опциональный параметр
  #тип - строка
  #используется при создании
  #kubelet_config = "{JSON string}"

  #используется для настройки поведения и параметров присоединения node к кластеру
  #он включает в себя такие параметры, как режим прокси-сервера, диапазоны IP-адресов кластера и другие конфигурации, специфичные для Kube-proxy
  #опциональный параметр
  #тип - строка
  #используется при создании
  #kube_proxy_config = "{JSON string}"

  #используется для настройки поведения и параметров присоединения node к кластеру
  #он включает в себя такие параметры, как cluster's control plane endpoint, токен и ключ сертификата
  #опциональный параметр
  #тип - строка
  #используется при создании
  #join_config = "{JSON string}"

  #при создании кластере использовать подключение только к сети ExtNet
  #опциональный параметр
  #тип - булев
  #используется при создании
  #extnet_only = true

  #добавить ssl-сертификат в формате x509 pem
  #опциональный параметр
  #тип - файл с форматом в виде .crt
  #используется при создании
  #oidc_cert = file("ca.crt")

  #тип эмулируемой системы
  #опциональный параметр
  #тип - строка
  #используется при создании
  #chipset = "i440fx"

  #пользовательские значения sysctl для LB
  #опциональный параметр
  #тип - массив мап
  #используется при создании и обновлении
  #lb_sysctl_params = [{ key1 = "value1", key2 = "value2" }]
}

output "cp_out" {
  value = decort_cb_k8s_cp.cp
}
